.. _debops.neurodebian:

debops.neurodebian
==================

The ``debops.neurodebian`` role allows you to configure the NeuroDebian__
repository and install packages from it.

NeuroDebian provides a large collection of popular neuroscience research
software for the Debian operating system as well as Ubuntu and other
derivatives.

.. __: http://neuro.debian.net/

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.neurodebian/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
